@@ -21,7 +21,7 @@ class CLIException(Exception):
             fix: (if defined) what steps can be taken to fix the error
             exit_code: what the exit code should be if this exception was raised
         """
-        super().__init__(self)
+        super().__init__(message)
 
         self.message = message
         self.fix = fix
